Attribute VB_Name = "OPOS"

' /////////////////////////////////////////////////////////////////////
' //
' // Opos.h
' //
' //   General header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' // 97-06-04 OPOS Release 1.2                                     CRM
' //   Add OPOS_FOREVER.
' //   Add BinaryConversion values.
' // 98-03-06 OPOS Release 1.3                                     CRM
' //   Add CapPowerReporting, PowerState, and PowerNotify values.
' //   Add power reporting values for StatusUpdateEvent.
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // OPOS "State" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_S_CLOSED As Long = 1&  
Public Const OPOS_S_IDLE As Long = 2&  
Public Const OPOS_S_BUSY As Long = 3&  
Public Const OPOS_S_ERROR As Long = 4&  

' /////////////////////////////////////////////////////////////////////
' // OPOS "ResultCode" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOSERR As Long = 100&  
Public Const OPOSERREXT As Long = 200&  

Public Const OPOS_SUCCESS As Long = 0&  
Public Const OPOS_E_CLOSED As Long = 1& + OPOSERR  
Public Const OPOS_E_CLAIMED As Long = 2& + OPOSERR  
Public Const OPOS_E_NOTCLAIMED As Long = 3& + OPOSERR  
Public Const OPOS_E_NOSERVICE As Long = 4& + OPOSERR  
Public Const OPOS_E_DISABLED As Long = 5& + OPOSERR  
Public Const OPOS_E_ILLEGAL As Long = 6& + OPOSERR  
Public Const OPOS_E_NOHARDWARE As Long = 7& + OPOSERR  
Public Const OPOS_E_OFFLINE As Long = 8& + OPOSERR  
Public Const OPOS_E_NOEXIST As Long = 9& + OPOSERR  
Public Const OPOS_E_EXISTS As Long = 10& + OPOSERR  
Public Const OPOS_E_FAILURE As Long = 11& + OPOSERR  
Public Const OPOS_E_TIMEOUT As Long = 12& + OPOSERR  
Public Const OPOS_E_BUSY As Long = 13& + OPOSERR  
Public Const OPOS_E_EXTENDED As Long = 14& + OPOSERR  

' /////////////////////////////////////////////////////////////////////
' // OPOS "BinaryConversion" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_BC_NONE As Long = 0&  
Public Const OPOS_BC_NIBBLE As Long = 1&  
Public Const OPOS_BC_DECIMAL As Long = 2&  

' /////////////////////////////////////////////////////////////////////
' // "CheckHealth" Method: "Level" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_CH_INTERNAL As Long = 1&  
Public Const OPOS_CH_EXTERNAL As Long = 2&  
Public Const OPOS_CH_INTERACTIVE As Long = 3&  

' /////////////////////////////////////////////////////////////////////
' // OPOS "CapPowerReporting", "PowerState", "PowerNotify" Property
' //   Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_PR_NONE As Long = 0&  
Public Const OPOS_PR_STANDARD As Long = 1&  
Public Const OPOS_PR_ADVANCED As Long = 2&  

Public Const OPOS_PN_DISABLED As Long = 0&  
Public Const OPOS_PN_ENABLED As Long = 1&  

Public Const OPOS_PS_UNKNOWN As Long = 2000&  
Public Const OPOS_PS_ONLINE As Long = 2001&  
Public Const OPOS_PS_OFF As Long = 2002&  
Public Const OPOS_PS_OFFLINE As Long = 2003&  
Public Const OPOS_PS_OFF_OFFLINE As Long = 2004&  

' /////////////////////////////////////////////////////////////////////
' // "ErrorEvent" Event: "ErrorLocus" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_EL_OUTPUT As Long = 1&  
Public Const OPOS_EL_INPUT As Long = 2&  
Public Const OPOS_EL_INPUT_DATA As Long = 3&  

' /////////////////////////////////////////////////////////////////////
' // "ErrorEvent" Event: "ErrorResponse" Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_ER_RETRY As Long = 11&  
Public Const OPOS_ER_CLEAR As Long = 12&  
Public Const OPOS_ER_CONTINUEINPUT As Long = 13&  

' /////////////////////////////////////////////////////////////////////
' // "StatusUpdateEvent" Event: Common "Status" Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_SUE_POWER_ONLINE As Long = 2001&  
Public Const OPOS_SUE_POWER_OFF As Long = 2002&  
Public Const OPOS_SUE_POWER_OFFLINE As Long = 2003&  
Public Const OPOS_SUE_POWER_OFF_OFFLINE As Long = 2004&  

' /////////////////////////////////////////////////////////////////////
' // General Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_FOREVER As Long = -1&  

' /////////////////////////////////////////////////////////////////////
' //
' // OposCash.h
' //
' //   Cash Drawer header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' // 98-03-06 OPOS Release 1.3                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "StatusUpdateEvent" Event Constants
' /////////////////////////////////////////////////////////////////////

Public Const CASH_SUE_DRAWERCLOSED As Long = 0&  
Public Const CASH_SUE_DRAWEROPEN As Long = 1&  

' /////////////////////////////////////////////////////////////////////
' //
' // OposCoin.h
' //
' //   Coin Dispenser header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "DispenserStatus" Property Constants
' // "StatusUpdateEvent" Event: "Data" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const COIN_STATUS_OK As Long = 1&  
Public Const COIN_STATUS_EMPTY As Long = 2&  
Public Const COIN_STATUS_NEAREMPTY As Long = 3&  
Public Const COIN_STATUS_JAM As Long = 4&  

' /////////////////////////////////////////////////////////////////////
' //
' // OposTot.h
' //
' //   Hard Totals header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "ResultCodeExtended" Property Constants for Hard Totals
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_ETOT_NOROOM As Long = 1& + OPOSERREXT       ' // Create, Write
Public Const OPOS_ETOT_VALIDATION As Long = 2& + OPOSERREXT     ' // Read, Write

' /////////////////////////////////////////////////////////////////////
' //
' // OposLock.h
' //
' //   Keylock header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "KeyPosition" Property Constants
' // "WaitForKeylockChange" Method: "KeyPosition" Parameter
' // "StatusUpdateEvent" Event: "Data" Parameter
' /////////////////////////////////////////////////////////////////////

Public Const LOCK_KP_ANY As Long = 0&              ' // WaitForKeylockChange Only
Public Const LOCK_KP_LOCK As Long = 1&  
Public Const LOCK_KP_NORM As Long = 2&  
Public Const LOCK_KP_SUPR As Long = 3&  

' /////////////////////////////////////////////////////////////////////
' //
' // OposDisp.h
' //
' //   Line Display header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' // 96-03-18 OPOS Release 1.01                                    CRM
' //   Add DISP_MT_INIT constant and MarqueeFormat constants.
' // 96-04-22 OPOS Release 1.1                                     CRM
' //   Add CapCharacterSet values for Kana and Kanji.
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "CapBlink" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_CB_NOBLINK As Long = 0&  
Public Const DISP_CB_BLINKALL As Long = 1&  
Public Const DISP_CB_BLINKEACH As Long = 2&  

' /////////////////////////////////////////////////////////////////////
' // "CapCharacterSet" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_CCS_NUMERIC As Long = 0&  
Public Const DISP_CCS_ALPHA As Long = 1&  
Public Const DISP_CCS_ASCII As Long = 998&  
Public Const DISP_CCS_KANA As Long = 10&  
Public Const DISP_CCS_KANJI As Long = 11&  

' /////////////////////////////////////////////////////////////////////
' // "CharacterSet" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_CS_ASCII As Long = 998&  
Public Const DISP_CS_WINDOWS As Long = 999&  

' /////////////////////////////////////////////////////////////////////
' // "MarqueeType" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_MT_NONE As Long = 0&  
Public Const DISP_MT_UP As Long = 1&  
Public Const DISP_MT_DOWN As Long = 2&  
Public Const DISP_MT_LEFT As Long = 3&  
Public Const DISP_MT_RIGHT As Long = 4&  
Public Const DISP_MT_INIT As Long = 5&  

' /////////////////////////////////////////////////////////////////////
' // "MarqueeFormat" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_MF_WALK As Long = 0&  
Public Const DISP_MF_PLACE As Long = 1&  

' /////////////////////////////////////////////////////////////////////
' // "DisplayText" Method: "Attribute" Property Constants
' // "DisplayTextAt" Method: "Attribute" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_DT_NORMAL As Long = 0&  
Public Const DISP_DT_BLINK As Long = 1&  

' /////////////////////////////////////////////////////////////////////
' // "ScrollText" Method: "Direction" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_ST_UP As Long = 1&  
Public Const DISP_ST_DOWN As Long = 2&  
Public Const DISP_ST_LEFT As Long = 3&  
Public Const DISP_ST_RIGHT As Long = 4&  

' /////////////////////////////////////////////////////////////////////
' // "SetDescriptor" Method: "Attribute" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const DISP_SD_OFF As Long = 0&  
Public Const DISP_SD_ON As Long = 1&  
Public Const DISP_SD_BLINK As Long = 2&  

' /////////////////////////////////////////////////////////////////////
' //
' // OposMicr.h
' //
' //   MICR header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "CheckType" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const MICR_CT_PERSONAL As Long = 1&  
Public Const MICR_CT_BUSINESS As Long = 2&  
Public Const MICR_CT_UNKNOWN As Long = 99&  

' /////////////////////////////////////////////////////////////////////
' // "CountryCode" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const MICR_CC_USA As Long = 1&  
Public Const MICR_CC_CANADA As Long = 2&  
Public Const MICR_CC_MEXICO As Long = 3&  
Public Const MICR_CC_UNKNOWN As Long = 99&  

' /////////////////////////////////////////////////////////////////////
' // "ResultCodeExtended" Property Constants for MICR
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_EMICR_NOCHECK As Long = 1& + OPOSERREXT   ' // EndInsertion
Public Const OPOS_EMICR_CHECK As Long = 2& + OPOSERREXT     ' // EndRemoval

' /////////////////////////////////////////////////////////////////////
' //
' // OposMsr.h
' //
' //   Magnetic Stripe Reader header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' // 97-06-04 OPOS Release 1.2                                     CRM
' //   Add ErrorReportingType values.
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "TracksToRead" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const MSR_TR_1 As Long = 1&  
Public Const MSR_TR_2 As Long = 2&  
Public Const MSR_TR_3 As Long = 4&  

Public Const MSR_TR_1_2 As Long = MSR_TR_1 Or MSR_TR_2  
Public Const MSR_TR_1_3 As Long = MSR_TR_1 Or MSR_TR_3  
Public Const MSR_TR_2_3 As Long = MSR_TR_2 Or MSR_TR_3  

Public Const MSR_TR_1_2_3 As Long = MSR_TR_1 Or MSR_TR_2 Or MSR_TR_3  

' /////////////////////////////////////////////////////////////////////
' // "ErrorReportingType" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const MSR_ERT_CARD As Long = 0&  
Public Const MSR_ERT_TRACK As Long = 1&  

' /////////////////////////////////////////////////////////////////////
' // "ErrorEvent" Event: "ResultCodeExtended" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_EMSR_START As Long = 1& + OPOSERREXT  
Public Const OPOS_EMSR_END As Long = 2& + OPOSERREXT  
Public Const OPOS_EMSR_PARITY As Long = 3& + OPOSERREXT  
Public Const OPOS_EMSR_LRC As Long = 4& + OPOSERREXT  

' /////////////////////////////////////////////////////////////////////
' //
' // OposPtr.h
' //
' //   POS Printer header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' // 96-04-22 OPOS Release 1.1                                     CRM
' //   Add CapCharacterSet values.
' //   Add ErrorLevel values.
' //   Add TransactionPrint Control values.
' // 97-06-04 OPOS Release 1.2                                     CRM
' //   Remove PTR_RP_NORMAL_ASYNC.
' //   Add more barcode symbologies.
' // 98-03-06 OPOS Release 1.3                                     CRM
' //   Add more PrintTwoNormal constants.
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // Printer Station Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_S_JOURNAL As Long = 1&  
Public Const PTR_S_RECEIPT As Long = 2&  
Public Const PTR_S_SLIP As Long = 4&  

Public Const PTR_S_JOURNAL_RECEIPT As Long = PTR_S_JOURNAL Or PTR_S_RECEIPT  
Public Const PTR_S_JOURNAL_SLIP As Long = PTR_S_JOURNAL Or PTR_S_SLIP  
Public Const PTR_S_RECEIPT_SLIP As Long = PTR_S_RECEIPT Or PTR_S_SLIP  

Public Const PTR_TWO_RECEIPT_JOURNAL As Long = &H8000& + PTR_S_JOURNAL_RECEIPT  
Public Const PTR_TWO_SLIP_JOURNAL As Long = &H8000& + PTR_S_JOURNAL_SLIP  
Public Const PTR_TWO_SLIP_RECEIPT As Long = &H8000& + PTR_S_RECEIPT_SLIP  

' /////////////////////////////////////////////////////////////////////
' // "CapCharacterSet" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_CCS_ALPHA As Long = 1&  
Public Const PTR_CCS_ASCII As Long = 998&  
Public Const PTR_CCS_KANA As Long = 10&  
Public Const PTR_CCS_KANJI As Long = 11&  

' /////////////////////////////////////////////////////////////////////
' // "CharacterSet" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_CS_ASCII As Long = 998&  
Public Const PTR_CS_WINDOWS As Long = 999&  

' /////////////////////////////////////////////////////////////////////
' // "ErrorLevel" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_EL_NONE As Long = 1&  
Public Const PTR_EL_RECOVERABLE As Long = 2&  
Public Const PTR_EL_FATAL As Long = 3&  

' /////////////////////////////////////////////////////////////////////
' // "MapMode" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_MM_DOTS As Long = 1&  
Public Const PTR_MM_TWIPS As Long = 2&  
Public Const PTR_MM_ENGLISH As Long = 3&  
Public Const PTR_MM_METRIC As Long = 4&  

' /////////////////////////////////////////////////////////////////////
' // "CutPaper" Method Constant
' /////////////////////////////////////////////////////////////////////

Public Const PTR_CP_FULLCUT As Long = 100&  

' /////////////////////////////////////////////////////////////////////
' // "PrintBarCode" Method Constants:
' /////////////////////////////////////////////////////////////////////

' //   "Alignment" Parameter
' //     Either the distance from the left-most print column to the start
' //     of the bar code, or one of the following:

Public Const PTR_BC_LEFT As Long = -1&  
Public Const PTR_BC_CENTER As Long = -2&  
Public Const PTR_BC_RIGHT As Long = -3&  

' //   "TextPosition" Parameter

Public Const PTR_BC_TEXT_NONE As Long = -11&  
Public Const PTR_BC_TEXT_ABOVE As Long = -12&  
Public Const PTR_BC_TEXT_BELOW As Long = -13&  

' //   "Symbology" Parameter:

' //     One dimensional symbologies
Public Const PTR_BCS_UPCA As Long = 101&            ' // Digits
Public Const PTR_BCS_UPCE As Long = 102&            ' // Digits
Public Const PTR_BCS_JAN8 As Long = 103&            ' // = EAN 8
Public Const PTR_BCS_EAN8 As Long = 103&            ' // = JAN 8 (added in 1.2)
Public Const PTR_BCS_JAN13 As Long = 104&           ' // = EAN 13
Public Const PTR_BCS_EAN13 As Long = 104&           ' // = JAN 13 (added in 1.2)
Public Const PTR_BCS_TF As Long = 105&              ' // (Discrete 2 of 5) Digits
Public Const PTR_BCS_ITF As Long = 106&             ' // (Interleaved 2 of 5) Digits
Public Const PTR_BCS_Codabar As Long = 107&         ' // Digits, -, $, :, /, ., +;
                                                    ' //   4 start/stop characters
                                                    ' //   (a, b, c, d)
Public Const PTR_BCS_Code39 As Long = 108&          ' // Alpha, Digits, Space, -, .,
                                                    ' //   $, /, +, %; start/stop (*)
                                                    ' // Also has Full ASCII feature
Public Const PTR_BCS_Code93 As Long = 109&          ' // Same characters as Code 39
Public Const PTR_BCS_Code128 As Long = 110&         ' // 128 data characters
                                                    ' //        (The following were added in Release 1.2)
Public Const PTR_BCS_UPCA_S As Long = 111&          ' // UPC-A with supplemental
                                                    ' //   barcode
Public Const PTR_BCS_UPCE_S As Long = 112&          ' // UPC-E with supplemental
                                                    ' //   barcode
Public Const PTR_BCS_UPCD1 As Long = 113&           ' // UPC-D1
Public Const PTR_BCS_UPCD2 As Long = 114&           ' // UPC-D2
Public Const PTR_BCS_UPCD3 As Long = 115&           ' // UPC-D3
Public Const PTR_BCS_UPCD4 As Long = 116&           ' // UPC-D4
Public Const PTR_BCS_UPCD5 As Long = 117&           ' // UPC-D5
Public Const PTR_BCS_EAN8_S As Long = 118&          ' // EAN 8 with supplemental
                                                    ' //   barcode
Public Const PTR_BCS_EAN13_S As Long = 119&         ' // EAN 13 with supplemental
                                                    ' //   barcode
Public Const PTR_BCS_EAN128 As Long = 120&          ' // EAN 128
Public Const PTR_BCS_OCRA As Long = 121&            ' // OCR "A"
Public Const PTR_BCS_OCRB As Long = 122&            ' // OCR "B"

' //     Two dimensional symbologies
Public Const PTR_BCS_PDF417 As Long = 201&  
Public Const PTR_BCS_MAXICODE As Long = 202&  

' //     Start of Printer-Specific bar code symbologies
Public Const PTR_BCS_OTHER As Long = 501&  

' /////////////////////////////////////////////////////////////////////
' // "PrintBitmap" Method Constants:
' /////////////////////////////////////////////////////////////////////

' //   "Width" Parameter
' //     Either bitmap width or:

Public Const PTR_BM_ASIS As Long = -11&            ' // One pixel per printer dot

' //   "Alignment" Parameter
' //     Either the distance from the left-most print column to the start
' //     of the bitmap, or one of the following:

Public Const PTR_BM_LEFT As Long = -1&  
Public Const PTR_BM_CENTER As Long = -2&  
Public Const PTR_BM_RIGHT As Long = -3&  

' /////////////////////////////////////////////////////////////////////
' // "RotatePrint" Method: "Rotation" Parameter Constants
' // "RotateSpecial" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_RP_NORMAL As Long = &H1&  
Public Const PTR_RP_RIGHT90 As Long = &H101&  
Public Const PTR_RP_LEFT90 As Long = &H102&  
Public Const PTR_RP_ROTATE180 As Long = &H103&  

' /////////////////////////////////////////////////////////////////////
' // "SetLogo" Method: "Location" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_L_TOP As Long = 1&  
Public Const PTR_L_BOTTOM As Long = 2&  

' /////////////////////////////////////////////////////////////////////
' // "TransactionPrint" Method: "Control" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_TP_TRANSACTION As Long = 11&  
Public Const PTR_TP_NORMAL As Long = 12&  

' /////////////////////////////////////////////////////////////////////
' // "StatusUpdateEvent" Event: "Data" Parameter Constants
' /////////////////////////////////////////////////////////////////////

Public Const PTR_SUE_COVER_OPEN As Long = 11&  
Public Const PTR_SUE_COVER_OK As Long = 12&  

Public Const PTR_SUE_JRN_EMPTY As Long = 21&  
Public Const PTR_SUE_JRN_NEAREMPTY As Long = 22&  
Public Const PTR_SUE_JRN_PAPEROK As Long = 23&  

Public Const PTR_SUE_REC_EMPTY As Long = 24&  
Public Const PTR_SUE_REC_NEAREMPTY As Long = 25&  
Public Const PTR_SUE_REC_PAPEROK As Long = 26&  

Public Const PTR_SUE_SLP_EMPTY As Long = 27&  
Public Const PTR_SUE_SLP_NEAREMPTY As Long = 28&  
Public Const PTR_SUE_SLP_PAPEROK As Long = 29&  

Public Const PTR_SUE_IDLE As Long = 1001&  

' /////////////////////////////////////////////////////////////////////
' // "ResultCodeExtended" Property Constants for Printer
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_EPTR_COVER_OPEN As Long = 1& + OPOSERREXT   ' // (Several)
Public Const OPOS_EPTR_JRN_EMPTY As Long = 2& + OPOSERREXT      ' // (Several)
Public Const OPOS_EPTR_REC_EMPTY As Long = 3& + OPOSERREXT      ' // (Several)
Public Const OPOS_EPTR_SLP_EMPTY As Long = 4& + OPOSERREXT      ' // (Several)
Public Const OPOS_EPTR_SLP_FORM As Long = 5& + OPOSERREXT       ' // EndRemoval
Public Const OPOS_EPTR_TOOBIG As Long = 6& + OPOSERREXT         ' // PrintBitmap
Public Const OPOS_EPTR_BADFORMAT As Long = 7& + OPOSERREXT      ' // PrintBitmap

' /////////////////////////////////////////////////////////////////////
' //
' // OposScal.h
' //
' //   Scale header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "WeightUnit" Property Constants
' /////////////////////////////////////////////////////////////////////

Public Const SCAL_WU_GRAM As Long = 1&  
Public Const SCAL_WU_KILOGRAM As Long = 2&  
Public Const SCAL_WU_OUNCE As Long = 3&  
Public Const SCAL_WU_POUND As Long = 4&  

' /////////////////////////////////////////////////////////////////////
' // "ResultCodeExtended" Property Constants for Scale
' /////////////////////////////////////////////////////////////////////

Public Const OPOS_ESCAL_OVERWEIGHT As Long = 1& + OPOSERREXT   ' // ReadWeight

' /////////////////////////////////////////////////////////////////////
' //
' // OposScan.h
' //
' //   Scanner header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' // 97-06-04 OPOS Release 1.2                                     CRM
' //   Add "ScanDataType" values.
' //
' /////////////////////////////////////////////////////////////////////

' /////////////////////////////////////////////////////////////////////
' // "ScanDataType" Property Constants
' /////////////////////////////////////////////////////////////////////

' // One dimensional symbologies
Public Const SCAN_SDT_UPCA As Long = 101&        ' // Digits
Public Const SCAN_SDT_UPCE As Long = 102&        ' // Digits
Public Const SCAN_SDT_JAN8 As Long = 103&        ' // = EAN 8
Public Const SCAN_SDT_EAN8 As Long = 103&        ' // = JAN 8 (added in 1.2)
Public Const SCAN_SDT_JAN13 As Long = 104&       ' // = EAN 13
Public Const SCAN_SDT_EAN13 As Long = 104&       ' // = JAN 13 (added in 1.2)
Public Const SCAN_SDT_TF As Long = 105&          ' // (Discrete 2 of 5) Digits
Public Const SCAN_SDT_ITF As Long = 106&         ' // (Interleaved 2 of 5) Digits
Public Const SCAN_SDT_Codabar As Long = 107&     ' // Digits, -, $, :, /, ., +;
                                                 ' //   4 start/stop characters
                                                 ' //   (a, b, c, d)
Public Const SCAN_SDT_Code39 As Long = 108&      ' // Alpha, Digits, Space, -, .,
                                                 ' //   $, /, +, %; start/stop (*)
                                                 ' // Also has Full ASCII feature
Public Const SCAN_SDT_Code93 As Long = 109&      ' // Same characters as Code 39
Public Const SCAN_SDT_Code128 As Long = 110&     ' // 128 data characters

Public Const SCAN_SDT_UPCA_S As Long = 111&        ' // UPC-A with supplemental
                                                   ' //   barcode
Public Const SCAN_SDT_UPCE_S As Long = 112&        ' // UPC-E with supplemental
                                                   ' //   barcode
Public Const SCAN_SDT_UPCD1 As Long = 113&         ' // UPC-D1
Public Const SCAN_SDT_UPCD2 As Long = 114&         ' // UPC-D2
Public Const SCAN_SDT_UPCD3 As Long = 115&         ' // UPC-D3
Public Const SCAN_SDT_UPCD4 As Long = 116&         ' // UPC-D4
Public Const SCAN_SDT_UPCD5 As Long = 117&         ' // UPC-D5
Public Const SCAN_SDT_EAN8_S As Long = 118&        ' // EAN 8 with supplemental
                                                   ' //   barcode
Public Const SCAN_SDT_EAN13_S As Long = 119&       ' // EAN 13 with supplemental
                                                   ' //   barcode
Public Const SCAN_SDT_EAN128 As Long = 120&        ' // EAN 128
Public Const SCAN_SDT_OCRA As Long = 121&          ' // OCR "A"
Public Const SCAN_SDT_OCRB As Long = 122&          ' // OCR "B"

' // Two dimensional symbologies
Public Const SCAN_SDT_PDF417 As Long = 201&  
Public Const SCAN_SDT_MAXICODE As Long = 202&  

' // Special cases
Public Const SCAN_SDT_OTHER As Long = 501&        ' // Start of Scanner-Specific bar
                                                  ' //   code symbologies
Public Const SCAN_SDT_UNKNOWN As Long = 0&        ' // Cannot determine the barcode
                                                  ' //   symbology.

' /////////////////////////////////////////////////////////////////////
' //
' // OposSig.h
' //
' //   Signature Capture header file for OPOS Applications.
' //
' // Modification history
' // ------------------------------------------------------------------
' // 95-12-08 OPOS Release 1.0                                     CRM
' //
' /////////////////////////////////////////////////////////////////////

' // No definitions required for this version.

